function check_command_context() {
    local runcnf=1;

    if [[ ! -x '/usr/bin/ocai' ]]; then
        runcnf=0;
    fi

    if [ -n "$ZSH_VERSION" ]; then 
        if [[ ! -o interactive ]]; then
            return 0;
        fi

        case $ZSH_EVAL_CONTEXT in *:file:*) return 0;; esac
    elif [ -n "$BASH_VERSION" ]; then
        if [[ $- != *i* ]]; then
            return 0;
        fi

        if [[ "${FUNCNAME[@]: -1}" = "source" ]]; then
            return 0;
        fi
    fi

    return $runcnf
}

function bash_command_not_found_handle() {
    local command="$@"
    local command_str="$command"

    check_command_context
    exec_agent=$?
    if [[ $exec_agent == 1 ]]; then
        ocai not_found "$command_str"
    else
        echo "Bash: $1: command not found"
    fi

    return 127
}

function zsh_command_not_found_handle() {
    local command="$@"
    local command_str="$command"

    check_command_context
    exec_agent=$?
    if [[ $exec_agent == 1 ]]; then
        ocai not_found "$command_str"
        return 0
    else
        return 127
    fi
}

function init_oc_not_found_handle {
    local SHELL_NAME=$(basename "$SHELL")
    case $SHELL_NAME in
    bash)
        # 执行 bash 安装脚本
        local rc_file="/etc/bashrc"
        new_handle=$(echo "$(declare -f bash_command_not_found_handle)" | sed 's/bash_command_not_found_handle/command_not_found_handle/')
        local install_tips="\033[32mocai-agent installation is complete. Please run \"source /etc/bashrc\" or open a new terminal to enable the configuration.\033[0m"
        local command_name="/etc/oc-bash-command-not-found"
        ;;
    zsh)
        # 执行 zsh 安装脚本
        local rc_file="/etc/zshrc"
        new_handle=$(echo "$(declare -f zsh_command_not_found_handle)" | sed 's/zsh_command_not_found_handle/command_not_found_handler/')
        local install_tips="\033[32mocai-agent installation is complete. Please run \"source /etc/zshrc\" or open a new terminal to enable the configuration.\033[0m"
        local command_name="/etc/oc-zsh-command-not-found"
        # zsh 脚本内容
        ;;
    *)
        # 其他 shell，不支持 not_found 功能
        echo "\033[32mocai-agent not_found functionality is not supported for $SHELL_NAME, finished install.\033[0m"
        exit 1
        ;;
    esac

    [ -f $command_name ] && > $command_name
    echo "$(declare -f check_command_context)" >> $command_name
    echo "$new_handle" >> $command_name
    echo ". $command_name" >> $rc_file
    echo -e $install_tips
}

init_oc_not_found_handle
